==> arirang-1.77.tar.gz: arirang-1.77/report.c <==
/*
 * Copyright 2010 pilot <pilot@monkey.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/utsname.h>

#include <stdio.h>
#include <stdlib.h>

#include "arirang.h"
#include "version.h"

void
htmlhead(char *htmlfile)
{
    FILE *fd;
    
        if ((fd = fopen(htmlfile, "a+")) == NULL) {
                fprintf(stderr, "File %s write error\n", htmlfile);
                exit(1);
        }

    fputs("<title>arirang scan report file</title>", fd);
    fputs("<br><table border=\"0\" cellpadding=\"3\" cellspacing=\"0\" width=\"80%\" bordercolor=\"#FFFFFF\">", fd);
    fputs("<tr><td width=\"80%\" align=\"right\" bgcolor=\"#505FAF\">", fd);
    fputs("<font size=\"2\" color=\"#FFFFFF\">Don't tell your web server free from attack-  arirang 1.77 report</a></font></td></tr>", fd);
    fputs("<tr><td width=\"80%\" align=\"right\" bgcolor=\"#505FAF\"><font size=\"2\" color=\"#FFFFFF\"> </font>", fd);
    fputs("</td></tr>\n", fd);
    fputs("<tr><td width=\"80%\" align=\"right\" bgcolor=\"#505FAF\">\n", fd);
    fputs("<font size=\"2\" color=\"#FFFFFF\">(c) 2001-2002, 2010 by pilot <a href=\"http://monkey.org/~pilot/arirang/\">\n", fd);
    fputs("http://monkey.org/~pilot/arirang/</a></font></td></tr></table>\n\n", fd);

    fclose(fd);
}

void
htmltail(char *htmlfile)
{
}

==> arirang-1.95.tar.gz: arirang-1.95/report.c <==
/*
 * Copyright 2010 pilot <pilot@monkey.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/utsname.h>

#include <stdio.h>
#include <stdlib.h>

#include "arirang.h"
#include "version.h"

void
htmlhead(char *htmlfile)
{
    FILE *fd;
    
        if ((fd = fopen(htmlfile, "a+")) == NULL) {
                fprintf(stderr, "File %s write error\n", htmlfile);
                exit(1);
        }

    fputs("<title>arirang scan report file</title>", fd);
    fputs("<br><table border=\"0\" cellpadding=\"3\" cellspacing=\"0\" width=\"80%\" bordercolor=\"#FFFFFF\">", fd);
    fputs("<tr><td width=\"80%\" align=\"right\" bgcolor=\"#505FAF\">", fd);
    fprintf(fd, "<font size=\"2\" color=\"#FFFFFF\">%s - arirang %s report</a></font></td></tr>", TITLE, VERSION);
    fputs("<tr><td width=\"80%\" align=\"right\" bgcolor=\"#505FAF\"><font size=\"2\" color=\"#FFFFFF\"> </font>", fd);
    fputs("</td></tr>\n", fd);
    fputs("<tr><td width=\"80%\" align=\"right\" bgcolor=\"#505FAF\">\n", fd);
    fputs("<font size=\"2\" color=\"#FFFFFF\">(c) 2001-2002, 2010 by pilot&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;", fd);
    fputs("<a href=\"http://monkey.org/~pilot/arirang/\">\n", fd);
    fputs("http://monkey.org/~pilot/arirang/</a></font></td></tr></table>\n\n", fd);

    fclose(fd);
}

void
htmlbody(FILE *fd)
{
}

void
htmltail(char *htmlfile)
{
}

void 
htmlrequest(FILE *fd)
{
}

void 
htmlreponse(FILE *fd)
{
}

void 
htmlurl(FILE *fd)
{
}

void 
htmlexplain(FILE *fd)
{
}

void 
htmlinfo(FILE *fd)
{
}

void 
htmlstyle(FILE *fd)
{
}
